.. MobsPy documentation master file, created by
   sphinx-quickstart on Wed Nov 15 15:09:36 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to MobsPy's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents

   Notebooks/01_Basic_Intro
   Notebooks/02_Reaction_Inheritance
   Notebooks/03_Characteristics
   Notebooks/04_Characteristic_restriction
   Notebooks/05_For_Loops
   Notebooks/06_Order_Matters
   Notebooks/07_Initial_Condition
   Notebooks/08_Units
   Notebooks/09_Result_Data
   Notebooks/10_Reaction_Rates
   Notebooks/11_Looping_Through_Species
   Notebooks/12_Born_Species
   Notebooks/13_Events
   Notebooks/14_Concatenating_Simulations

.. toctree::
   :maxdepth: 2
   :caption: API

   api